@@ -48,8 +48,8 @@
 #define READ   0
 #define WRITE 1
 
-static char *local_foldername;
-static char *local_diskname;
+static char *local_foldername=NULL;
+static char *local_diskname=NULL;
 static gboolean flag_to_umount;
 static gboolean flag_to_mount;
 static gint added_disk_is_ok;
@@ -61,6 +61,8 @@ static GString *message_to_display;
 
 static gboolean vfs_scan_nok;
 
+static GtkWidget *stop_window = NULL;
+
 gint
 spawn_proc (gchar * path, gint narg, gchar ** arg)
 {
@@ -336,8 +338,11 @@ do_not_forget_to_mount (gboolean gb)
 void
 set_added_disk (gint gb)
 {
-  if ((gb == ADDED_DISK_UNDEF) || (added_disk_is_ok == ADDED_DISK_UNDEF))
-    added_disk_is_ok = gb;
+  if ((gb == ADDED_DISK_DELETE) || (gb == ADDED_DISK_STOP)
+      || (gb == ADDED_DISK_UNDEF) || (added_disk_is_ok == ADDED_DISK_UNDEF))
+    {
+      added_disk_is_ok = gb;
+    }
 }
 
 void
@@ -346,6 +351,12 @@ init_vfs_scan_status (void)
   vfs_scan_nok = FALSE;
 }
 
+static void
+destroy_window (GtkWidget * w, GdkEventKey * event, gpointer data)
+{
+  gtk_widget_destroy (w);
+}
+
 gint my_timeout (gpointer data)
 {
   FOLDER *racine = data;
@@ -354,6 +365,8 @@ gint my_timeout (gpointer data)
   if ((get_thread_status () == THREAD_SCAN_RUNNING_ENDED)
       && (added_disk_is_ok != ADDED_DISK_UNDEF))
     {
+      if (added_disk_is_ok == ADDED_DISK_STOP)
+	added_disk_is_ok = ADDED_DISK_OK;
       if (added_disk_is_ok == ADDED_DISK_OK)
 	{
 	  gtk_clist_freeze (GTK_CLIST (racine->ctree));
@@ -367,12 +380,21 @@ gint my_timeout (gpointer data)
 	}
       else if (added_disk_is_ok == ADDED_DISK_DELETE)
 	{
-	  suppress_dir ((GNode *) local_gn);
+	  suppress_dir (local_gn, FALSE);
 	}
-      if (local_diskname)
+      if (stop_window)
+	{
+	  gtk_widget_destroy (stop_window);
+	  stop_window = NULL;
+	}
+      if (local_diskname) {
 	g_free (local_diskname);
-      if (local_foldername)
+	local_diskname = NULL;
+	}
+      if (local_foldername) {
 	g_free (local_foldername);
+	local_foldername = NULL;
+	}
 /************** If umount and eject have to be in the main thread, remove the comments ********/
 //umount_and_eject_if_necessary();
 /*********************************************************************************************/
@@ -386,6 +408,7 @@ gint my_timeout (gpointer data)
 			  ("At least one VFS could not be read successfully"),
 			  main_window);
 	}
+
     }
   else
     {
@@ -395,6 +418,52 @@ gint my_timeout (gpointer data)
   return (0);
 }
 
+void
+fad_wait_window_cb (GtkWidget * w, gpointer data)
+{
+  set_added_disk (GPOINTER_TO_INT (data));
+  gtk_widget_destroy (stop_window);
+  stop_window = NULL;
+}
+
+void
+fad_wait_window (void)
+{
+  GtkWidget *label;
+
+  /* Window */
+  stop_window = gnome_dialog_new (_("Wait"),
+				  _("Stop"), GNOME_STOCK_BUTTON_CANCEL, NULL);
+
+  /* FIXME: Set Parent to help the window manager */
+  //gnome_dialog_set_parent(GNOME_DIALOG(dlg), GTK_WINDOW(app));
+
+  gtk_window_set_position (GTK_WINDOW (stop_window), GTK_WIN_POS_MOUSE);
+
+  /* Label */
+  label = gtk_label_new (_("Stop:   Stop the scan and keep the disk.\n"
+                           "Cancel: Stop the scan and remove the disk."));
+  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (stop_window)->vbox), label, TRUE,
+		      TRUE, 0);
+  gtk_widget_show (label);
+
+  /* Callbacks */
+  gnome_dialog_button_connect (GNOME_DIALOG (stop_window), 0,
+			       fad_wait_window_cb,
+			       GINT_TO_POINTER (ADDED_DISK_STOP));
+  gnome_dialog_button_connect (GNOME_DIALOG (stop_window), 1,
+			       fad_wait_window_cb,
+			       GINT_TO_POINTER (ADDED_DISK_DELETE));
+
+  gtk_window_set_transient_for (GTK_WINDOW (stop_window),
+				GTK_WINDOW (main_window));
+  gtk_signal_connect (GTK_OBJECT (stop_window),
+		      "delete_event", destroy_window, NULL);
+  gtk_widget_realize (stop_window);
+  gtk_widget_show (stop_window);
+
+}
+
 void
 set_local_disk_name (gchar * s)
 {
@@ -550,6 +619,12 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   gchar *mime;
   gpointer scan_it;
 
+  if (added_disk_is_ok == ADDED_DISK_DELETE)
+    return (FALSE);
+
+  if (added_disk_is_ok == ADDED_DISK_STOP)
+    return (FALSE);
+
   if (progress_needReset ())
     {
       progress_reset ();
@@ -568,7 +643,9 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
       printf ("Can't read the directory: %s", my_path->str);
       return (FALSE);
     }
-  while ((fichier = readdir (dir)) != NULL)
+  while (((fichier = readdir (dir)) != NULL)
+	 && (added_disk_is_ok != ADDED_DISK_DELETE)
+	 && (added_disk_is_ok != ADDED_DISK_STOP))
     {
       file = g_strconcat (my_path->str, fichier->d_name, NULL);
       if ((strcmp (fichier->d_name, ".") != 0)
@@ -678,7 +755,8 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   closedir (dir);
   g_string_free (my_path, TRUE);
 
-  while (new_dirs)
+  while ((new_dirs) && (added_disk_is_ok != ADDED_DISK_DELETE)
+	 && (added_disk_is_ok != ADDED_DISK_STOP))
     {
       gn = (GNode *) new_dirs->data;
       file = g_strconcat (path, "/", folder_get_name (gn), NULL);
