@@ -25,6 +25,7 @@
 #define ADDED_DISK_OK		1
 #define ADDED_DISK_NOK		2
 #define ADDED_DISK_DELETE	3
+#define ADDED_DISK_STOP		4
 
 guint du_s (gchar * path);
 gboolean eject_disk(CONFIG *my_config);
@@ -42,6 +43,8 @@ void init_vfs_scan_status(void);
 
 gint my_timeout (gpointer data);
 
+void fad_wait_window (void);
+
 gchar *read_information (gchar * file, gchar * mime);
 gboolean create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 			 gboolean getInformation, gint testvfs);
