@@ -30,12 +30,19 @@
 #define USER_CONFIG_DIR "/.gtktalog"
 #define USER_CONFIG_FILE "gtktalog.cf"
 
+#define FSTAB_FILE "/etc/fstab"
+
 #define CATEGORY_MAX_LENGTH 64
 #define DEFINITION_MAX_LENGTH 1024
 #define INFORMATION_MAX_LENGTH 128
 #define READLINE_MAX_LENGTH 2048
 
 #define MAX_STRING_LENGTH 1024
+/*
+ *	IIRC, and ISO CD can't have more than 20 chars in its
+ *	label? Shouldn't pose a problem, now should it? 
+ */
+#define MAX_DISK_LABEL_LENGTH 20
 
 #define CAT_TREE_UP	1
 #define CAT_TREE_DOWN	2
@@ -209,6 +216,7 @@ typedef struct
   GString *umount;
   GString *eject_prog;
   GString *mount_point;
+  GString *mount_device;
   GString *dummy_prog;
   gboolean use_supermount;
   gboolean use_automount;
@@ -218,6 +226,8 @@ typedef struct
   gboolean use_du_s;
   gboolean warn_mount;
   gboolean eject_disk;
+  gboolean read_cd_name;
+  gboolean validate_cd_name;
   gboolean dbclick_opens_info;
   gboolean display_dir_size;
   gboolean save_only_used_categories;
