@@ -27,30 +27,32 @@ typedef union {
 #define	OPTIONDUS	274
 #define	OPTIONWARNMOUNT	275
 #define	OPTIONEJECT	276
-#define	COMPRESSIONLEVEL	277
-#define	TESTVFS	278
-#define	VFSEXTENSION	279
-#define	MIMEEXTENSION	280
-#define	MIMEVFSEXTENSION	281
-#define	READINFORMATION	282
-#define	DEFAULTMIMEEXTENSION	283
-#define	SCANMIMETYPES	284
-#define	ADDMIMETOSKIP	285
-#define	USEDEFAULTMIMEPLUGIN	286
-#define	DBCLICKFORINFO	287
-#define	DISPLAYDIRSIZE	288
-#define	DATEFORMAT	289
-#define	RECENTFILE	290
-#define	RECENTFILESMAX	291
-#define	PREVIOUSSEARCHMODE	292
-#define	SAVEONLYUSEDCATEGORIES	293
-#define	MAINWINDOWPOSITION	294
-#define	STRING	295
-#define	QSTRING	296
-#define	GBOOLEAN	297
-#define	STRINGLOCALE	298
-#define	INTEGER	299
-#define	EOL	300
+#define	READCDNAME	277
+#define	VALIDATECDNAME	278
+#define	COMPRESSIONLEVEL	279
+#define	TESTVFS	280
+#define	VFSEXTENSION	281
+#define	MIMEEXTENSION	282
+#define	MIMEVFSEXTENSION	283
+#define	READINFORMATION	284
+#define	DEFAULTMIMEEXTENSION	285
+#define	SCANMIMETYPES	286
+#define	ADDMIMETOSKIP	287
+#define	USEDEFAULTMIMEPLUGIN	288
+#define	DBCLICKFORINFO	289
+#define	DISPLAYDIRSIZE	290
+#define	DATEFORMAT	291
+#define	RECENTFILE	292
+#define	RECENTFILESMAX	293
+#define	PREVIOUSSEARCHMODE	294
+#define	SAVEONLYUSEDCATEGORIES	295
+#define	MAINWINDOWPOSITION	296
+#define	STRING	297
+#define	QSTRING	298
+#define	GBOOLEAN	299
+#define	STRINGLOCALE	300
+#define	INTEGER	301
+#define	EOL	302
 
 
 extern YYSTYPE yylval;
