@@ -225,7 +225,7 @@ delete_folder (GtkWidget * w, FOLDER * racine)
   GNode *parent;
   parent = racine->selected_folder->parent;
   gtk_clist_freeze (GTK_CLIST (racine->ctree));
-  suppress_dir (racine->selected_folder);
+  suppress_dir (racine->selected_folder, TRUE);
   description_garbage_collection ();
   gtk_clist_thaw (GTK_CLIST (racine->ctree));
   list_folder (parent, TRUE);
@@ -576,7 +576,7 @@ update_disk (GtkWidget * w, FOLDER * racine)
   disk_name = g_strdup (folder_get_name (parent));
   folder_name = g_strdup (folder_get_informations (parent));
 
-  suppress_dir (racine->selected_folder);
+  suppress_dir (racine->selected_folder, TRUE);
   gtk_clist_clear (GTK_CLIST (clist));
   start_add_disk (folder_name, disk_name, racine);
   g_free (folder_name);
