@@ -85,27 +85,27 @@ get_disk_label (char *dev_name)
       char *buf;
       int was_read = 0;
       unsigned char buf2[32809];
-		/* (comments by David Erman <di97der@student.hk-r.se>)
-		 * Why 32808 bytes? Well, after doing a:
-		 * 
-		 *  dd count=70 if=/dev/cdrom
-		 * 
-		 * that's where I found the title of the CD
-		 *  basically. I couldn't find any docs on the
-		 *  ISO9660 filesystem, so I'm not sure why this is
-		 *  but it seems to be a consistent value. Looks
-		 *  like it might be the fs header there, since
-		 *  there is info on the creator and such as well.
-		 *  
-		 *  Thus, we fseek 32808 bytes, which will amount to
-		 *  16 2048-byte blocks; 2048 byte blocks are used on
-		 *  ISO9660 CD's right?
-		 *
-		 *  I'm not sure this'll work on HFS CD's, but there you go.
-		 */
+      /* (comments by David Erman <di97der@student.hk-r.se>)
+       * Why 32808 bytes? Well, after doing a:
+       * 
+       *  dd count=70 if=/dev/cdrom
+       * 
+       * that's where I found the title of the CD
+       *  basically. I couldn't find any docs on the
+       *  ISO9660 filesystem, so I'm not sure why this is
+       *  but it seems to be a consistent value. Looks
+       *  like it might be the fs header there, since
+       *  there is info on the creator and such as well.
+       *  
+       *  Thus, we fseek 32808 bytes, which will amount to
+       *  16 2048-byte blocks; 2048 byte blocks are used on
+       *  ISO9660 CD's right?
+       *
+       *  I'm not sure this'll work on HFS CD's, but there you go.
+       */
 
       fread (buf2, 4101, 8, inf);
-      buf = (char *) g_malloc (MAX_DISK_LABEL_LENGTH+1);
+      buf = (char *) g_malloc (MAX_DISK_LABEL_LENGTH + 1);
       was_read = fread (buf, MAX_DISK_LABEL_LENGTH, 1, inf);
 
       fclose (inf);
@@ -201,7 +201,6 @@ fad_create_window (gchar ** fast_name)
   return -1;
 }
 
-
 void
 fast_add_disk (FOLDER * racine)
 {
@@ -211,20 +210,20 @@ fast_add_disk (FOLDER * racine)
   do_not_forget_to_mount (TRUE);
   if ((my_config->mount_device) && (my_config->read_cd_name))
     {
-      if (my_config->fast_name)
+      gchar *tmp;
+      tmp = get_disk_label (my_config->mount_device->str);
+      if (tmp)
 	{
-	  gchar *tmp;
-	  tmp = get_disk_label (my_config->mount_device->str);
-	  if (tmp)
+	  if (my_config->fast_name)
 	    {
 	      free (my_config->fast_name);
-	      my_config->fast_name = tmp;
-	      set_local_disk_name (my_config->fast_name);
-	    }
-	  else
-	    {
-	      set_local_disk_name (g_strdup (""));
 	    }
+	  my_config->fast_name = tmp;
+	  set_local_disk_name (my_config->fast_name);
+	}
+      else
+	{
+	  set_local_disk_name (g_strdup (""));
 	}
     }
   set_local_folder_name (escapespaces (my_config->mount_point->str));
@@ -251,6 +250,7 @@ fast_add_disk (FOLDER * racine)
 	{
 	  set_local_disk_name (my_config->fast_name);
 	  set_added_disk (ADDED_DISK_OK);
+	  fad_wait_window ();
 	}
       else
 	{
@@ -267,6 +267,7 @@ fast_add_disk (FOLDER * racine)
     {
       set_local_disk_name (my_config->fast_name);
       set_added_disk (ADDED_DISK_OK);
+      fad_wait_window ();
     }
   else
     {
