@@ -606,7 +606,7 @@ gboolean _gnode_clear_ctree_data (GNode * gn, gpointer data)
 }
 
 void
-suppress_dir (GNode * dir)
+suppress_dir (GNode * dir, gboolean suppress_gui)
 {
   FOLDER *racine;
   GPtrArray *gpa;
@@ -625,15 +625,17 @@ suppress_dir (GNode * dir)
 
   fd = dir->data;
 
-  if ((is_dir (dir) == TRUE) || (is_disk (dir) == TRUE)
-      || (is_vfs_any (dir) == TRUE) || (G_NODE_IS_ROOT (dir) == TRUE))
+  if (suppress_gui)
     {
-      g_node_traverse (dir, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
-		       _gnode_clear_ctree_data, racine);
-      if (G_NODE_IS_ROOT (dir) != TRUE)
-	gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
+      if ((is_dir (dir) == TRUE) || (is_disk (dir) == TRUE)
+	  || (is_vfs_any (dir) == TRUE) || (G_NODE_IS_ROOT (dir) == TRUE))
+	{
+	  g_node_traverse (dir, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
+			   _gnode_clear_ctree_data, racine);
+	  if (!G_NODE_IS_ROOT (dir))
+	    gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
+	}
     }
-
   g_node_traverse (dir, G_PRE_ORDER, G_TRAVERSE_ALL, -1, _gnode_clear_data,
 		   racine);
 
@@ -845,7 +847,7 @@ clear_folder (FOLDER * racine)
 
   if (racine->tree)
     {
-      suppress_dir (racine->tree);
+      suppress_dir (racine->tree, TRUE);
     }
 
   if (racine->descriptions)
@@ -892,7 +894,7 @@ gboolean _scan_folders_for_stats (GNode * gn, gpointer data)
       stats[3]++;
       if (is_in_vfs_any (gn))
 	stats[1]++;
-      else if (is_file (gn))
+      else if ((is_file (gn)) || (is_vfs_any (gn)))
 	{
 	  fd = get_file_data_from_gnode (gn);
 	  stats[5] += (fd->taille % 1048576);	/* 1024^2 = 1048576 */
