@@ -119,8 +119,6 @@ traverse_add_dir_to_clist (GNode * gn, gpointer data)
 
       i = gtk_clist_append (GTK_CLIST (clist), (gchar **) temp);
 
-      g_free ((gpointer) temp[1]);
-      g_free ((gpointer) temp[2]);
       if (is_dir (gn) == TRUE)
 	pix = my_config->default_dir_pix;
       else if (is_vfs_any (gn) == TRUE)
@@ -130,6 +128,8 @@ traverse_add_dir_to_clist (GNode * gn, gpointer data)
       gtk_clist_set_pixtext (GTK_CLIST (clist), i, 0,
 			     fd->name->str, 3, pix->pixmap, *(pix->mask));
       gtk_clist_set_row_data (GTK_CLIST (clist), i, gn);
+      g_free ((gpointer) temp[1]);
+      g_free ((gpointer) temp[2]);
     }
 }
 
@@ -179,8 +179,6 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 
       i = gtk_clist_append (GTK_CLIST (clist), (gchar **) temp);
 
-      g_free ((gpointer) temp[1]);
-      g_free ((gpointer) temp[2]);
       pix = get_pix_from_gnode (gn);
 
       gtk_clist_set_pixtext (GTK_CLIST (clist), i, 0,
@@ -188,6 +186,8 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 
 
       gtk_clist_set_row_data (GTK_CLIST (clist), i, gn);
+      g_free ((gpointer) temp[1]);
+      g_free ((gpointer) temp[2]);
 
     }
 }
@@ -786,7 +786,7 @@ set_currently_displayed_folder_pixtext (FOLDER * racine, gboolean is_open)
 				      NULL, NULL);
 	  gtk_ctree_node_set_pixtext (GTK_CTREE (racine->ctree),
 				      fd->ctree_node, 0,
-				      dir_text, 4, pix->pixmap, *(pix->mask));
+				      g_strdup(dir_text), 4, pix->pixmap, *(pix->mask));
 	  gn = gn->parent;
 
 	}
