@@ -169,6 +169,11 @@ update_vfs_fd (GNode * gn, gpointer data)
       g_node_traverse (gn, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 		       set_vfs_extended_fd, NULL);
     }
+  if (is_vfs_any (gn))
+    {
+      FILE_DATA *fd = get_file_data_from_gnode (gn);
+      fd->a_parent_node_is_vfs = IS_FILE;
+    }
   return (FALSE);
 }
 
