@@ -190,6 +190,7 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
   gchar *myname;
   GPtrArray *splitted_name;
   gchar *myseparator;
+  gint i;
 
   gchar *strsize;
   guint32 size;
@@ -202,7 +203,7 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
   myseparator = convert_string_with_slashes (ve->separator->str);
   result = extract_field (line, myseparator, fields);
   g_free (myseparator);
-  g_array_free (fields, FALSE);
+  g_array_free (fields, TRUE);
   if (result->len >= 2)
     {
 
@@ -213,7 +214,6 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
 	size = atoi (strsize);
       else
 	size = 0;
-      g_free (strsize);
 
 /* Get the date */
 /****************/
@@ -290,7 +290,6 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
 	}
       else
 	date = 0;
-      g_free (g_ptr_array_index (result, 1));
 
 /* Work on the name */
 /********************/
@@ -301,7 +300,6 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
 	    splitted_name = split_name (myname + 2);
 	  else
 	    splitted_name = split_name (myname);
-	  g_free (myname);
 	}
       else
 	{
@@ -309,13 +307,19 @@ insert_node_from_vfsline (GNode * vfs_node, gchar * line,
 	}
       create_vfs_node (vfs_node, splitted_name, splitted_name->len, size,
 		       date, IS_FILE, testvfs);
-      g_ptr_array_free (splitted_name, TRUE);
 
-      g_ptr_array_free (result, FALSE);
+      for (i = 0; i < splitted_name->len; i++)
+	g_free (g_ptr_array_index (splitted_name, i));
+      for (i = 0; i < result->len; i++)
+	g_free (g_ptr_array_index (result, i));
+      g_ptr_array_free (splitted_name, TRUE);
+      g_ptr_array_free (result, TRUE);
       return (FALSE);
     }
   else
     {
+      for (i = 0; i < result->len; i++)
+	g_free (g_ptr_array_index (result, i));
       g_ptr_array_free (result, TRUE);
       return (TRUE);
     }
